ValidatedSetting

Trait ValidatedSetting 

pub trait ValidatedSetting {
    // Required method
    fn validate(&mut self);
}
Trait for validating and normalizing setting values. Mandatory to implement for all types used with SettingsPlugin. Called automatically after loading (including from file), after reloading, after default(), as well as before saving and when setting a new value via the PersistSetting event. If validation is not needed, implement the method as empty.

Required Methods

fn validate(&mut self)

Implementors